# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main.ui'
#
# Created by: PyQt5 UI code generator 5.14.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets
import os

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setWindowIcon(QtGui.QIcon(f"{os.path.dirname(os.path.realpath(__file__))}/icons/icon256.png"))
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.setFixedSize(630, 280)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        MainWindow.setFont(font)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.mailDomainInput = QtWidgets.QLineEdit(self.centralwidget)
        self.mailDomainInput.setEnabled(False)
        self.mailDomainInput.setGeometry(QtCore.QRect(30, 190, 251, 25))
        self.mailDomainInput.setObjectName("mailDomainInput")
        self.atLabel = QtWidgets.QLabel(self.centralwidget)
        self.atLabel.setEnabled(True)
        self.atLabel.setGeometry(QtCore.QRect(10, 190, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(12)
        self.atLabel.setFont(font)
        self.atLabel.setObjectName("atLabel")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 40, 271, 141))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.radioE2U = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioE2U.setEnabled(False)
        self.radioE2U.setObjectName("radioE2U")
        self.buttonGroup = QtWidgets.QButtonGroup(MainWindow)
        self.buttonGroup.setObjectName("buttonGroup")
        self.buttonGroup.addButton(self.radioE2U)
        self.verticalLayout.addWidget(self.radioE2U)
        self.radioEP2UP = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioEP2UP.setEnabled(False)
        self.radioEP2UP.setObjectName("radioEP2UP")
        self.buttonGroup.addButton(self.radioEP2UP)
        self.verticalLayout.addWidget(self.radioEP2UP)
        self.radioU2E = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioU2E.setEnabled(False)
        self.radioU2E.setObjectName("radioU2E")
        self.buttonGroup.addButton(self.radioU2E)
        self.verticalLayout.addWidget(self.radioU2E)
        self.radioUP2EP = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioUP2EP.setEnabled(False)
        self.radioUP2EP.setObjectName("radioUP2EP")
        self.buttonGroup.addButton(self.radioUP2EP)
        self.verticalLayout.addWidget(self.radioUP2EP)
        self.importBtn = QtWidgets.QPushButton(self.centralwidget)
        self.importBtn.setGeometry(QtCore.QRect(10, 10, 271, 25))
        self.importBtn.setObjectName("importBtn")
        self.convertBtn = QtWidgets.QPushButton(self.centralwidget)
        self.convertBtn.setEnabled(False)
        self.convertBtn.setGeometry(QtCore.QRect(10, 220, 271, 31))
        self.convertBtn.setObjectName("convertBtn")
        self.textArea = QtWidgets.QPlainTextEdit(self.centralwidget)
        self.textArea.setGeometry(QtCore.QRect(290, 10, 329, 211))
        self.textArea.setObjectName("textArea")
        self.horizontalLayoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.horizontalLayoutWidget.setGeometry(QtCore.QRect(290, 230, 331, 27))
        self.horizontalLayoutWidget.setObjectName("horizontalLayoutWidget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.saveTxtBtn = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.saveTxtBtn.setObjectName("saveTxtBtn")
        self.horizontalLayout.addWidget(self.saveTxtBtn)
        self.copyTxtBtn = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.copyTxtBtn.setObjectName("copyTxtBtn")
        self.horizontalLayout.addWidget(self.copyTxtBtn)
        self.clearTxtBtn = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.clearTxtBtn.setObjectName("clearTxtBtn")
        self.horizontalLayout.addWidget(self.clearTxtBtn)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 628, 22))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.actionCopy = QtWidgets.QAction(MainWindow)
        self.actionCopy.setCheckable(False)
        self.actionCopy.setObjectName("actionCopy")
        self.actionCut = QtWidgets.QAction(MainWindow)
        self.actionCut.setObjectName("actionCut")
        self.actionPaste = QtWidgets.QAction(MainWindow)
        self.actionPaste.setObjectName("actionPaste")
        self.actionUndo = QtWidgets.QAction(MainWindow)
        self.actionUndo.setObjectName("actionUndo")
        self.actionRedo = QtWidgets.QAction(MainWindow)
        self.actionRedo.setObjectName("actionRedo")
        self.mb_import = QtWidgets.QAction(MainWindow)
        self.mb_import.setObjectName("mb_import")
        self.mb_save = QtWidgets.QAction(MainWindow)
        self.mb_save.setEnabled(False)
        self.mb_save.setObjectName("mb_save")
        self.mb_undo = QtWidgets.QAction(MainWindow)
        self.mb_undo.setObjectName("mb_undo")
        self.mb_redo = QtWidgets.QAction(MainWindow)
        self.mb_redo.setObjectName("mb_redo")
        self.mb_cut = QtWidgets.QAction(MainWindow)
        self.mb_cut.setObjectName("mb_cut")
        self.mb_copy = QtWidgets.QAction(MainWindow)
        self.mb_copy.setObjectName("mb_copy")
        self.mb_paste = QtWidgets.QAction(MainWindow)
        self.mb_paste.setObjectName("mb_paste")
        self.mb_about = QtWidgets.QAction(MainWindow)
        self.mb_about.setIconVisibleInMenu(True)
        self.mb_about.setObjectName("mb_about")
        self.mb_howto = QtWidgets.QAction(MainWindow)
        self.mb_howto.setObjectName("mb_howto")
        self.mb_report = QtWidgets.QAction(MainWindow)
        self.mb_report.setObjectName("mb_report")
        self.menuFile.addAction(self.mb_import)
        self.menuFile.addAction(self.mb_save)
        self.menuEdit.addAction(self.mb_undo)
        self.menuEdit.addAction(self.mb_redo)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.mb_cut)
        self.menuEdit.addAction(self.mb_copy)
        self.menuEdit.addAction(self.mb_paste)
        self.menuHelp.addAction(self.mb_about)
        self.menuHelp.addAction(self.mb_howto)
        self.menuHelp.addAction(self.mb_report)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("UserMail Converter", "UserMail Converter"))
        self.mailDomainInput.setPlaceholderText(_translate("MainWindow", "eg: gmail.com"))
        self.atLabel.setText(_translate("MainWindow", "@"))
        self.radioE2U.setText(_translate("MainWindow", "Email > Username"))
        self.radioEP2UP.setText(_translate("MainWindow", "Email:Pass > Username:Pass"))
        self.radioU2E.setText(_translate("MainWindow", "Username > Email"))
        self.radioUP2EP.setText(_translate("MainWindow", "Username:Pass > Email:Pass"))
        self.importBtn.setText(_translate("MainWindow", "Import File"))
        self.convertBtn.setText(_translate("MainWindow", "Convert"))
        self.textArea.setPlaceholderText(_translate("MainWindow", "paste list here or import a file"))
        self.saveTxtBtn.setText(_translate("MainWindow", "Save"))
        self.copyTxtBtn.setText(_translate("MainWindow", "Copy"))
        self.clearTxtBtn.setText(_translate("MainWindow", "Clear"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.actionCopy.setText(_translate("MainWindow", "Copy"))
        self.actionCopy.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.actionCut.setText(_translate("MainWindow", "Cut"))
        self.actionCut.setShortcut(_translate("MainWindow", "Ctrl+X"))
        self.actionPaste.setText(_translate("MainWindow", "Paste"))
        self.actionPaste.setShortcut(_translate("MainWindow", "Ctrl+V"))
        self.actionUndo.setText(_translate("MainWindow", "Undo"))
        self.actionRedo.setText(_translate("MainWindow", "Redo"))
        self.mb_import.setText(_translate("MainWindow", "Import File"))
        self.mb_import.setShortcut(_translate("MainWindow", "Ctrl+I"))
        self.mb_save.setText(_translate("MainWindow", "Save As..."))
        self.mb_save.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.mb_undo.setText(_translate("MainWindow", "Undo"))
        self.mb_undo.setShortcut(_translate("MainWindow", "Ctrl+Z"))
        self.mb_redo.setText(_translate("MainWindow", "Redo"))
        self.mb_redo.setShortcut(_translate("MainWindow", "Ctrl+Y"))
        self.mb_cut.setText(_translate("MainWindow", "Cut"))
        self.mb_cut.setShortcut(_translate("MainWindow", "Ctrl+X"))
        self.mb_copy.setText(_translate("MainWindow", "Copy"))
        self.mb_copy.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.mb_paste.setText(_translate("MainWindow", "Paste"))
        self.mb_paste.setShortcut(_translate("MainWindow", "Ctrl+V"))
        self.mb_about.setText(_translate("MainWindow", "About"))
        self.mb_howto.setText(_translate("MainWindow", "How To"))
        self.mb_report.setText(_translate("MainWindow", "Report Issue"))



import sys
import webbrowser
from . import converters
from pyautogui import hotkey
from PyQt5.QtWidgets import QMainWindow, QApplication, QFileDialog, QMessageBox
from .UI import Ui_MainWindow

class App(QMainWindow, Ui_MainWindow):
    # Init the App
    def __init__(self):
        super(App, self).__init__()
        self.setupUi(self) # Preload the UI
        self.initWatchers() # Start the watchers/listners (howerver you call it :D)
        self.show() # Show the UI once everything is ready


    #Manages the Watchers/Listners for Different Buttons and Events Triggers
    def initWatchers(self):
        # Placeholders for variables
        self.version = "1.1"
        self.radioChecked = False
        self.radioBtns = [self.radioE2U, self.radioEP2UP, self.radioU2E, self.radioUP2EP]

        # Watchers/Listners for Events Triggers
        self.importBtn.clicked.connect(self.importFile)

        self.textArea.textChanged.connect(self.textAreaWatcher)

        self.copyTxtBtn.clicked.connect(lambda:self.textAreaBtnsManager("copy"))
        self.clearTxtBtn.clicked.connect(lambda:self.textAreaBtnsManager("clear"))
        self.saveTxtBtn.clicked.connect(lambda:self.textAreaBtnsManager("save"))

        for radio in self.radioBtns:
            radio.clicked.connect(lambda: self.btnsManager("convertOn"))

        self.convertBtn.clicked.connect(self.doConvert)

        self.mb_import.triggered.connect(self.importFile)
        self.mb_save.triggered.connect(self.saveFile)

        self.mb_cut.triggered.connect(lambda:hotkey("ctrl", "x"))
        self.mb_copy.triggered.connect(lambda:hotkey("ctrl", "c"))
        self.mb_paste.triggered.connect(lambda:hotkey("ctrl", "v"))

        self.mb_undo.triggered.connect(self.textArea.undo)
        self.mb_redo.triggered.connect(self.textArea.redo)

        self.mb_report.triggered.connect(lambda: webbrowser.open("https://github.com/ThamiMemel/UserMail_Converter/issues", 2, True))
        self.mb_howto.triggered.connect(lambda: self.popup("Help", "1- Past or Import a list to convert\n2-Select the conversion mode\n3- Enter the mail domain if converting usernames to emails\n4-Press convert", "info"))
        self.mb_about.triggered.connect(lambda: self.popup("About", f"UserMail Converter\nMade By: Thami Memel\nmemelthami@gmail.com\n\nversion: {self.version}\nLisence: GPLv3","info"))
    
    # Open the file selected by "openFileNameDialog" and set it's content to textArea if possible
    def importFile(self):
        filepath = self.openFileNameDialog()
        if filepath:
            try:
                with open(filepath) as f:
                    result = ""
                    for line in f:
                        result += line
                self.textArea.setPlainText(result)
            except Exception:
                # Popup error if it cannot read the file
                self.popup("Error", "Couldn't Import the File", "crit")


    # Save the content of textArea to a file
    def saveFile(self, data):
        filepath = self.saveFileDialog()
        if filepath:
            try:
                with open(filepath, "w") as f:
                    f.write(data)
                f.close()
                self.popup("Success", "File saved successfully", "info")
            except Exception:
                # Popup error if it cannot save the file
                self.popup("Error", "Couldn't save the file", "crit")
    

    #  Popup a message "QMessageBox"-
    def popup(self, title, message, mode):
        msg = QMessageBox()
        msg.setWindowTitle(title)
        msg.setText(message)
        if mode == "info": msg.setIcon(QMessageBox.Information)
        elif mode == "warn": msg.setIcon(QMessageBox.Warning)
        elif mode == "crit": msg.setIcon(QMessageBox.Critical)
        msg.exec_()


    # Open the file selection dialog and return the path to the file selected
    def openFileNameDialog(self):
        options = QFileDialog.Options()
        options |= QFileDialog.DontUseNativeDialog
        path, _ = QFileDialog.getOpenFileName(None, "Import a File", "","All Files (*);;Text Files (*.txt)", "/home", options=options)
        if path: return path


    # Open the file save dialog and return the path to save
    def saveFileDialog(self):
        options = QFileDialog.Options()
        options |= QFileDialog.DontUseNativeDialog
        path, ext = QFileDialog.getSaveFileName(self,"Save to a File","","Text Files (*.txt);;All Files (*)", options=options)
        if path:
            ext = ext[ext.index("*") + 1:len(ext) - 1]
            return path + ext


    # Enables and Disables the radio and toolbar import buttons based on if there is a text or not
    def textAreaWatcher(self):
        if self.textArea.toPlainText():
            self.btnsManager("radioOn")
            self.mb_save.setEnabled(True)
        else:
            self.btnsManager("radioOff")
            self.mb_save.setEnabled(False)


    # Manages the textArea buttons (copy, clear and select all)
    def textAreaBtnsManager(self, action):
        if self.textArea.toPlainText(): # Make sure the text Area isn't empty
            if action == "copy":
                self.textArea.selectAll()
                self.textArea.copy()
                self.popup("copied", "text copied", "info")
            elif action == "save":
                self.saveFile(self.textArea.toPlainText())
            elif action == "clear":
                self.textArea.clear()
   

    # Manages enabling and disabling buttons 
    def btnsManager(self, mode):
        # Switching Mail Domain Input On and Off Depending On The Radio Button Checked
        def checkMailInput():
            # Enables mailDomainInput if user to email mode is selected
            if self.radioU2E.isChecked() or self.radioUP2EP.isChecked(): 
                self.mailDomainInput.setEnabled(True)
            # Disables mailDomainInput if not
            else: self.mailDomainInput.setEnabled(False)
        
        # Enables all radio buttons if n == 1, Disables them if n == 0
        def switchRadio(n):
            if n == 0: 
                self.convertBtn.setEnabled(False)
                self.mailDomainInput.setEnabled(False)
                # Disable all radio
                for radio in self.radioBtns:
                    radio.setEnabled(False)
            else:
                if self.radioChecked: self.convertBtn.setEnabled(True)
                checkMailInput() # Check if mailDomainInput should be enabled
                # Enable all radio
                for radio in self.radioBtns:
                    radio.setEnabled(True) 
        
        if mode == "radioOn": switchRadio(1)
        elif mode == "radioOff": switchRadio(0)
        elif mode == "convertOn":
            self.convertBtn.setEnabled(True)
            self.radioChecked = True # Set the glbal variable to be used by switchRadio(1)|btnsManager("radioOn")
            checkMailInput() # Check if mailDomainInput should be enabled
    

    # Simply convert :D
    def doConvert(self):
        # Make sure a domain is specified if required
        if not ((self.radioU2E.isChecked() or self.radioUP2EP.isChecked()) and self.mailDomainInput.text()):
            self.popup("Error", "Please enter a domain \n eg: gmail.com", "warn")
            return
        
        domain = self.mailDomainInput.text()
        converted = ""
        toConv = self.textArea.toPlainText()
        lines = toConv.split("\n") # Split text to lines list

        for line in lines:
            if line: # Get rid of emty line
                if self.radioE2U.isChecked():
                    converted += converters.mail_user(line)
                elif self.radioEP2UP.isChecked():
                    converted += converters.mailpass_userpass(line)
                elif self.radioU2E.isChecked():
                    converted += converters.user_mail(line, domain)
                elif self.radioUP2EP.isChecked():
                    converted += converters.userpass_mailpass(line, domain)
                converted += "\n" # New Line
        
        self.textArea.setPlainText(converted) # Update text area
        self.popup("Done", "Converted", "info")
                
def main():
    app = QApplication(sys.argv)
    ex = App()
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()




from setuptools import setup
from os import path

with open(path.join(path.abspath(path.dirname(__file__)), 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

version = "1.1"
setup(
  name = 'usermail_converter',
  packages = ['usermail_converter'],
  version = version,
  license='GPLv3',
  description = 'A Python Cross Platform GUI App Tool to Convert Between Emails and Usernames',
  long_description=long_description,
  long_description_content_type='text/markdown',
  author = 'Thami Memel',
  author_email = 'memelthami@gmail.com',
  url = 'https://github.com/ThamiMemel/UserMail_Converter',
  download_url = f'https://github.com/ThamiMemel/usermail-converter/archive/{version}.tar.gz',
  keywords = ['username', 'email', 'mail', 'converter', "combo"],  
  install_requires=[ 
          'pyqt5==5.14.2',
          'PyAutoGUI==0.9.50',
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable', #"3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: End Users/Desktop',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
    "Topic :: Utilities",
    "Natural Language :: English",
    "Operating System :: POSIX :: Linux",
    "Operating System :: MacOS",
    "Operating System :: Microsoft :: Windows",
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8"
  ],
  entry_points={
    'console_scripts': [
        'usermail-converter=usermail_converter.__main__:main',
        ],
    },
  package_data={'usermail_converter': ['icons/*']},
)


def mail_user(mail):
    if mail: #ignore emty strings
        try:
            username = mail[0:mail.index("@")]
            return username
        except Exception:
            return mail
    else: return mail


def mailpass_userpass(line):
    if line: # Ignore emtpy lines
        try:
            mail = line.split(":")[0]
            passswd = line.split(":")[1]
            convmail = mail_user(mail) #converted email
            if mail != convmail: return f"{convmail}:{passswd}"
            else: return line
        except Exception:
            return line
    else: return line


def user_mail(user, domain):
    if user: return f"{user}@{domain}"
    else: return user


def userpass_mailpass(line, domain):
    if line:
        try:
            user = line.split(":")[0]
            passswd = line.split(":")[1]
            convuser = user_mail(user,domain)
            return f"{convuser}:{passswd}"
        except Exception:
            return line
    else: return line
